@@ -23,12 +23,35 @@ void OptionsDialog::on_ssaverCheckBox_toggled(bool checked)
         emit ssaverInhibit(checked);
 }
 
+void OptionsDialog::on_albumIconsCheckBox_toggled(bool checked)
+{
+        emit albumIcons(checked);
+}
+void OptionsDialog::on_buttonBox_accepted()
+{
+    bool checked = false;
+    if (ui->largeAlbumIconsCheckBox->checkState() == Qt::Checked)
+    {
+        checked = true;
+    }
+    emit largeAlbumIcons(checked);
+}
 
 void OptionsDialog::setScreensaverInhibitedState(bool ssInhibited)
 {
     ui->ssaverCheckBox->setChecked(ssInhibited);
 }
 
+void OptionsDialog::setAlbumIconsState(bool albumIcons)
+{
+    ui->albumIconsCheckBox->setChecked(albumIcons);
+}
+
+void OptionsDialog::setLargeAlbumIconsState(bool largeAlbumIcons)
+{
+    ui->largeAlbumIconsCheckBox->setChecked(largeAlbumIcons);
+}
+
 void OptionsDialog::on_aboutPushButton_clicked()
 {
     //----------------------------------------------
